==> haskell-quote-quot-0.2.1.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quote-quot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quote-quot
version:              0.2.1.0
visibility:           public
id:                   quote-quot-0.2.1.0-Ex0ugtSmmLv4msBMfVBjbD
key:                  quote-quot-0.2.1.0-Ex0ugtSmmLv4msBMfVBjbD
license:              BSD-3-Clause
copyright:            2020-2022 Andrew Lelechenko
maintainer:           andrew.lelechenko@gmail.com
author:               Andrew Lelechenko
homepage:             https://github.com/Bodigrim/quote-quot#readme
synopsis:             Divide without division
description:
    Generate routines for integer division, employing arithmetic
    and bitwise operations only, which are __2.5x-3.5x faster__
    than '\''quot'\''. Divisors must be known in compile-time and be positive.

category:             Math, Numerical
abi:                  9ee6e5c11b4d3f43b0447c2e4f2c2c54
exposed:              True
exposed-modules:      Numeric.QuoteQuot
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quote-quot
hs-libraries:         HSquote-quot-0.2.1.0-Ex0ugtSmmLv4msBMfVBjbD
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-quote-quot/html/quote-quot.haddock
haddock-html:         /usr/share/doc/haskell-quote-quot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quote-quot-0.2.1.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quote-quot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quote-quot
version:              0.2.1.0
visibility:           public
id:                   quote-quot-0.2.1.0-EfrqmL5X4Eu4VAAoPbqkta
key:                  quote-quot-0.2.1.0-EfrqmL5X4Eu4VAAoPbqkta
license:              BSD-3-Clause
copyright:            2020-2022 Andrew Lelechenko
maintainer:           andrew.lelechenko@gmail.com
author:               Andrew Lelechenko
homepage:             https://github.com/Bodigrim/quote-quot#readme
synopsis:             Divide without division
description:
    Generate routines for integer division, employing arithmetic
    and bitwise operations only, which are __2.5x-3.5x faster__
    than '\''quot'\''. Divisors must be known in compile-time and be positive.

category:             Math, Numerical
abi:                  1e6603908728a6db7180f64e33fae564
exposed:              True
exposed-modules:      Numeric.QuoteQuot
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quote-quot-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quote-quot
hs-libraries:         HSquote-quot-0.2.1.0-EfrqmL5X4Eu4VAAoPbqkta
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-quote-quot/html/quote-quot.haddock
haddock-html:         /usr/share/doc/haskell-quote-quot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
